Renamed _testXXX to _testcapiXXX.  Jack is my hero -- good call!
diff --git a/Lib/test/test_capi.py b/Lib/test/test_capi.py
index 8b39829..9eddc88 100644
--- a/Lib/test/test_capi.py
+++ b/Lib/test/test_capi.py
@@ -1,16 +1,16 @@
 # Run the _test module tests (tests for the Python/C API):  by defn, these
 # are all functions _test exports whose name begins with 'test_'.
 
 import sys
 import test_support
-import _test
+import _testcapi
 
-for name in dir(_test):
+for name in dir(_testcapi):
     if name.startswith('test_'):
-        test = getattr(_test, name)
+        test = getattr(_testcapi, name)
         if test_support.verbose:
             print "internal", name
         try:
             test()
-        except _test.error:
+        except _testcapi.error:
             raise test_support.TestFailed, sys.exc_info()[1]
@@ -1,16 +1,16 @@
-# Run the _test module tests (tests for the Python/C API):  by defn, these
-# are all functions _test exports whose name begins with 'test_'.
+# Run the _testcapi module tests (tests for the Python/C API):  by defn,
+# these are all functions _test exports whose name begins with 'test_'.
 
 import sys